##  Step 5: Start the Development Server
Once you've updated HTML content, you can start the development server. Run the following command:

```
npm start
```



A new tab opens in your browser displaying your custom report in the Reports section within your SAP LeanIX environment. If the tab doesn't open, the command provides a link that you can copy and then paste into the address bar of your browser.
The following image shows the outcome of the script used in this tutorial.
![Custom Lifecycle Matrix Report for Application Fact Sheets](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757d2c27a4410148444f9a8dd9b183a_LowRes.png)
Custom Lifecycle Matrix Report for Application Fact Sheets
